from .endpoints.json import Json
from .endpoints.buffer import Buffer
from .endpoints.anime import Anime

__title__ = 'tokyo'
__author__ = 'Loxitoh'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022-present Loxitoh'
__version__ = '0.0.1'
